summaryrefslogtreecommitdiff
path: root/lib/ping.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/ping.php')
-rw-r--r--lib/ping.php12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/ping.php b/lib/ping.php
index d26c73417..175bf8440 100644
--- a/lib/ping.php
+++ b/lib/ping.php
@@ -1,7 +1,7 @@
<?php
/*
* Laconica - a distributed open-source microblogging tool
* Copyright (C) 2009, Control Yourself, Inc.
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as published by
@@ -17,7 +17,7 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-if (!defined('LACONICA')) { exit(1); }
+if (!defined('STATUSNET') && !defined('LACONICA')) { exit(1); }
function ping_broadcast_notice($notice) {
@@ -47,7 +47,7 @@ function ping_broadcast_notice($notice) {
$context = stream_context_create(array('http' => array('method' => "POST",
'header' =>
"Content-Type: text/xml\r\n".
- "User-Agent: Laconica/".LACONICA_VERSION."\r\n",
+ "User-Agent: StatusNet/".STATUSNET_VERSION."\r\n",
'content' => $req)));
$file = file_get_contents($notify_url, false, $context);
@@ -81,11 +81,11 @@ function ping_broadcast_notice($notice) {
if ($type === 'get') {
$result = $fetcher->get($notify_url . '?' . http_build_query($args),
- array('User-Agent: Laconica/'.LACONICA_VERSION));
+ array('User-Agent: StatusNet/'.STATUSNET_VERSION));
} else {
$result = $fetcher->post($notify_url,
http_build_query($args),
- array('User-Agent: Laconica/'.LACONICA_VERSION));
+ array('User-Agent: StatusNet/'.STATUSNET_VERSION));
}
if ($result->status != '200') {
common_log(LOG_WARNING,
@@ -1,7 +1,7 @@
<?php
/*
- * Laconica - a distributed open-source microblogging tool
- * Copyright (C) 2009, Control Yourself, Inc.
+ * StatusNet - the distributed open-source microblogging tool
+ * Copyright (C) 2009, StatusNet, Inc.
*
* This program is free software: you can redistribute it and/or modify